Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(915)

Unified Diff: chrome/browser/ui/cocoa/infobars/infobar_container_controller.h

Issue 11305008: Remove TabContents from TabStripModelObserverBridge. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/infobars/infobar_container_controller.h
diff --git a/chrome/browser/ui/cocoa/infobars/infobar_container_controller.h b/chrome/browser/ui/cocoa/infobars/infobar_container_controller.h
index 9779878e41967edda8109872457b49fcaa613df7..45639da084d284bdacbea237f9ed670bae191e20 100644
--- a/chrome/browser/ui/cocoa/infobars/infobar_container_controller.h
+++ b/chrome/browser/ui/cocoa/infobars/infobar_container_controller.h
@@ -17,9 +17,12 @@
class InfoBar;
class InfoBarDelegate;
class InfoBarNotificationObserver;
-class TabContents;
class TabStripModel;
+namespace content {
+class WebContents;
+}
+
// Protocol for basic container methods, as needed by an InfoBarController.
// This protocol exists to make mocking easier in unittests.
@protocol InfoBarContainer
@@ -51,8 +54,8 @@ const CGFloat kTipHeight = 12.0;
// Needed to send resize messages when infobars are added or removed.
id<ViewResizer> resizeDelegate_; // weak
- // The TabContents we are currently showing infobars for.
- TabContents* currentTabContents_; // weak
+ // The WebContents we are currently showing infobars for.
+ content::WebContents* currentWebContents_; // weak
// Holds the InfoBarControllers currently owned by this container.
scoped_nsobject<NSMutableArray> infobarControllers_;
@@ -85,12 +88,12 @@ const CGFloat kTipHeight = 12.0;
// infobars, removes them first and deregisters for any
// notifications. |contents| can be NULL, in which case no infobars
// are shown and no notifications are registered for.
-- (void)changeTabContents:(TabContents*)contents;
+- (void)changeWebContents:(content::WebContents*)contents;
// Stripped down version of TabStripModelObserverBridge:tabDetachedWithContents.
// Forwarded by BWC. Removes all infobars and deregisters for any notifications
// if |contents| is the current tab contents.
-- (void)tabDetachedWithContents:(TabContents*)contents;
+- (void)tabDetachedWithContents:(content::WebContents*)contents;
// Returns the number of active infobars. This is
// |infobarControllers_ - closingInfoBars_|.
« no previous file with comments | « chrome/browser/ui/cocoa/hung_renderer_controller.mm ('k') | chrome/browser/ui/cocoa/infobars/infobar_container_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698